@@ -1,5 +1,7 @@
 from django.contrib import admin
-from .models import Application, Grant, AccessToken, RefreshToken
+from .models import Grant, AccessToken, RefreshToken, get_application_model
+
+Application = get_application_model()
 
 admin.site.register(Application)
 admin.site.register(Grant)
