@@ -2,14 +2,14 @@ from __future__ import unicode_literals
 
 import json
 
+from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.test import TestCase, RequestFactory
 from django.views.generic import View
 
 from oauthlib.oauth2 import BackendApplicationServer
 
-from ..compat import get_user_model
-from ..models import Application
+from ..models import get_application_model
 from ..oauth2_validators import OAuth2Validator
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
@@ -17,6 +17,9 @@ from ..views.mixins import OAuthLibMixin
 from .test_utils import TestCaseUtils
 
 
+Application = get_application_model()
+
+
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
     def get(self, request, *args, **kwargs):
@@ -26,8 +29,8 @@ class ResourceView(ProtectedResourceView):
 class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = get_user_model().objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="test_client_credentials_app",
@@ -37,7 +40,7 @@ class BaseTest(TestCaseUtils, TestCase):
         )
         self.application.save()
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
 
     def tearDown(self):
         self.application.delete()
@@ -55,7 +58,7 @@ class TestClientCredential(BaseTest):
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
@@ -90,7 +93,7 @@ class TestExtendedRequest(BaseTest):
             'grant_type': 'client_credentials',
         }
         auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
-        response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
         content = json.loads(response.content.decode("utf-8"))
