@@ -1,14 +1,18 @@
 from __future__ import unicode_literals
 
 from django.test import TestCase, RequestFactory
+from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 
-from ..compat import urlparse, parse_qs, urlencode, get_user_model
-from ..models import Application
+from ..compat import urlparse, parse_qs, urlencode
+from ..models import get_application_model
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
 
+Application = get_application_model()
+
+
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
     def get(self, request, *args, **kwargs):
@@ -18,8 +22,8 @@ class ResourceView(ProtectedResourceView):
 class BaseTest(TestCase):
     def setUp(self):
         self.factory = RequestFactory()
-        self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
-        self.dev_user = get_user_model().objects.create_user("dev_user", "dev@user.com", "123456")
+        self.test_user = User.objects.create_user("test_user", "test@user.com", "123456")
+        self.dev_user = User.objects.create_user("dev_user", "dev@user.com", "123456")
 
         self.application = Application(
             name="Test Implicit Application",
@@ -30,7 +34,7 @@ class BaseTest(TestCase):
         )
         self.application.save()
 
-        oauth2_settings.SCOPES = ['read', 'write']
+        oauth2_settings._SCOPES = ['read', 'write']
 
     def tearDown(self):
         self.application.delete()
@@ -52,7 +56,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'scope': 'read write',
             'redirect_uri': 'http://example.it',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
@@ -60,7 +64,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
         # check form is in context and form params are valid
         self.assertIn("form", response.context)
 
-        form = response.context.get("form")
+        form = response.context["form"]
         self.assertEqual(form['redirect_uri'].value(), "http://example.it")
         self.assertEqual(form['state'].value(), "random_state_string")
         self.assertEqual(form['scopes'].value(), "read write")
@@ -76,7 +80,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'client_id': 'fakeclientid',
             'response_type': 'token',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 400)
@@ -91,12 +95,12 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'client_id': self.application.client_id,
             'response_type': 'token',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
-        form = response.context.get("form")
+        form = response.context["form"]
         self.assertEqual(form['redirect_uri'].value(), "http://localhost")
 
     def test_pre_auth_forbibben_redirect(self):
@@ -110,7 +114,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'response_type': 'token',
             'redirect_uri': 'http://forbidden.it',
         })
-        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
 
         response = self.client.get(url)
         self.assertEqual(response.status_code, 400)
@@ -130,7 +134,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'allow': True,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
         self.assertIn('http://example.it#', response['Location'])
         self.assertIn('access_token=', response['Location'])
@@ -151,7 +155,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
             'allow': False,
         }
 
-        response = self.client.post(reverse('authorize'), data=form_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
         self.assertIn("error=access_denied", response['Location'])
 
@@ -169,7 +173,7 @@ class TestImplicitTokenView(BaseTest):
             'response_type': 'token',
             'allow': True,
         }
-        response = self.client.post(reverse('authorize'), data=authcode_data)
+        response = self.client.post(reverse('oauth2_provider:authorize'), data=authcode_data)
         # within implicit grant, access token is in the url fragment
         frag_dict = parse_qs(urlparse(response['Location']).fragment)
         access_token = frag_dict['access_token'].pop()
@@ -183,4 +187,4 @@ class TestImplicitTokenView(BaseTest):
 
         view = ResourceView.as_view()
         response = view(request)
-        self.assertEqual(response, "This is a protected resource")
\ No newline at end of file
+        self.assertEqual(response, "This is a protected resource")
