@@ -7,5 +7,5 @@ admin.autodiscover()
 urlpatterns = patterns(
     '',
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^o/', include('oauth2_provider.urls')),
+    url(r'^o/', include('oauth2_provider.urls', namespace='oauth2_provider')),
 )
